@@ -936,7 +936,9 @@ orc_x86_compile (OrcCompiler *compiler)
       int l;
 
       save_loop_shift = compiler->loop_shift;
+#if 0 /* This looks verbose to me. T.Yano (2024.7.22) */
       compiler->vars[align_var].is_aligned = FALSE;
+#endif
 
       for (l = 0; l < save_loop_shift; l++) {
         compiler->loop_shift = l;
@@ -950,7 +952,9 @@ orc_x86_compile (OrcCompiler *compiler)
       }
 
       compiler->loop_shift = save_loop_shift;
+#if 0 /* This looks wrong to me. T.Yano (2024.7.22) */
       compiler->vars[align_var].is_aligned = TRUE;
+#endif
     }
 
     orc_x86_emit_label (compiler, LABEL_REGION1_SKIP);
